==> haskell-network-ip-0.3.0.3-386-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-network-ip.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 network-ip
version:              0.3.0.3
visibility:           public
id:                   network-ip-0.3.0.3-26soyffdXevAa6AUEEoQKU
key:                  network-ip-0.3.0.3-26soyffdXevAa6AUEEoQKU
license:              BSD-3-Clause
copyright:            2011-2016 Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
maintainer:           Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
author:               Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
stability:            experimental
homepage:             https://github.com/mvv/network-ip
synopsis:             Internet Protocol data structures
description:          This package provides Internet Protocol data structures
category:             Network
abi:                  4f8f948db3a8d03fc295f58b69c54756
exposed:              True
exposed-modules:      Network.IP.Addr
import-dirs:          /usr/lib/ghc-9.4.8/site-local/network-ip-0.3.0.3
library-dirs:         /usr/lib/ghc-9.4.8/site-local/network-ip-0.3.0.3
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/network-ip-0.3.0.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-network-ip
hs-libraries:         HSnetwork-ip-0.3.0.3-26soyffdXevAa6AUEEoQKU
depends:
    base-4.17.2.1 data-default-class-0.1.2.0-J3yYo85AtrC9KKZSpt62Yc
    data-dword-0.3.2.1-3mb40jgJ7Pi7BMZoocI039
    data-endian-0.1.1-7icaZ25RZK5C1z9LOhGoDG
    data-serializer-0.3.5-KJuUNNNecfd98nhlLiqKCi
    data-textual-0.3.0.3-DqFeg5sE3Wr3RgTepYVYu8
    hashable-1.4.4.0-LtdCyz5lRpSEDVfQGtCbHQ
    parsers-0.12.12-3nyhMVxcxoJ9rnBgdjjWM9
    text-printer-0.5.0.2-IsVA2sacFGHAQKuTsM9OUK
    type-hint-0.1-BLZkEIaqz7B91MRxOq10xP

haddock-interfaces:   /usr/share/doc/haskell-network-ip/html/network-ip.haddock
haddock-html:         /usr/share/doc/haskell-network-ip/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-network-ip-0.3.0.3-387-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-network-ip.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 network-ip
version:              0.3.0.3
visibility:           public
id:                   network-ip-0.3.0.3-LHMsmJkkikL3yC1sQPmHtR
key:                  network-ip-0.3.0.3-LHMsmJkkikL3yC1sQPmHtR
license:              BSD-3-Clause
copyright:            2011-2016 Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
maintainer:           Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
author:               Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
stability:            experimental
homepage:             https://github.com/mvv/network-ip
synopsis:             Internet Protocol data structures
description:          This package provides Internet Protocol data structures
category:             Network
abi:                  040b7999a0134acfe0ff781befdab862
exposed:              True
exposed-modules:      Network.IP.Addr
import-dirs:          /usr/lib/ghc-9.4.8/site-local/network-ip-0.3.0.3
library-dirs:         /usr/lib/ghc-9.4.8/site-local/network-ip-0.3.0.3
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/network-ip-0.3.0.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-network-ip
hs-libraries:         HSnetwork-ip-0.3.0.3-LHMsmJkkikL3yC1sQPmHtR
depends:
    base-4.17.2.1 data-default-class-0.1.2.0-J3yYo85AtrC9KKZSpt62Yc
    data-dword-0.3.2.1-DSOtYRWO6EQ30TsekoYWct
    data-endian-0.1.1-7icaZ25RZK5C1z9LOhGoDG
    data-serializer-0.3.5-CrI54oujj83Imm0X99Styd
    data-textual-0.3.0.3-DjAB7ZMalyNE7FNEE2vUjR
    hashable-1.4.4.0-9MfualSpDNWnshBkTCGL2
    parsers-0.12.12-Gg30xYDgWIsLUaRmDLfQS0
    text-printer-0.5.0.2-FwmHao4TOSpGQrReFRJdsP
    type-hint-0.1-BLZkEIaqz7B91MRxOq10xP

haddock-interfaces:   /usr/share/doc/haskell-network-ip/html/network-ip.haddock
haddock-html:         /usr/share/doc/haskell-network-ip/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
